@@ -3,10 +3,20 @@
 # main app for PloneController. Establishes
 # app and its frame; runs main loop.
 
+import sys
+import os
+import traceback
+
+if sys.platform == 'win32':
+    # Import pythoncom and pywintypes as soon as possible, to make
+    # sure they are found. This must happen before *any* import from
+    # pywin32 when you're in a 'relocatable' python build, like the
+    # Plone Windows Installer.
+    import pythoncom
+    import pywintypes
+
 import wx
 import wx.lib.mixins.inspection
-import sys, os, traceback
-
 import Notebook, config
 from config import debug
 
